@@ -11,5 +11,5 @@ pub mod locations;
 pub mod machines;
 pub mod moves;
 pub mod pokemon;
-pub mod resource;
+pub mod resources;
 pub mod utility;
